@@ -361,6 +361,9 @@ class Patcher(object):
             else:
                 self.infile = BytesIO("".encode("ascii"))
             self.outfile = open(self.new_target,"wb")
+            if os.path.isfile(self.target):
+                mod = os.stat(self.target).st_mode
+                os.chmod(self.new_target,mod)
 
     def _check_end_patch(self):
         """Finish patching the current file, if there is one.
@@ -1009,7 +1012,7 @@ class Differ(object):
         """
         t_nm = os.path.join(target,nm)
         if os.path.isfile(t_nm):
-             # For files, I haven't decided on a god heuristic yet...
+             # For files, I haven't decided on a good heuristic yet...
             return None
         elif os.path.isdir(t_nm):
             #  For directories, decide similarity based on the number of
